translate.misc.contextlib.closing

Package translate :: Package misc :: Module contextlib :: Class closing |
[hide private]
[frames] | no frames]

# Class closing

source code

    Context to automatically close something at the end of a block.

    Code like this:

        with closing(<module>.open(<arguments>)) as f:
            <block>

    is equivalent to this:

        f = <module>.open(<arguments>)
        try:
            <block>
        finally:
            f.close()

Instance Methods | [hide private]
__init__(self, thing) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__enter__(self) | source code
__exit__(self, *exc_info) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, thing) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)